@@ -36,7 +36,9 @@ class SwmmInput(CustomDict):
             **kwargs: only for creating the inp-object as a dict.
         """
         filename = None
-        if len(args) == 1 and isinstance(args[0], (str, Path)) and os.path.isfile(args[0]):
+        if (len(args) == 1) and isinstance(args[0], (str, Path)):
+            if not os.path.isfile(args[0]):
+                raise FileNotFoundError(args[0])
             # argument is an inp-file.
             super().__init__()
             filename = args[0]
